==> zio-aws-docdb_2.13-5.17.146.1-sources.jar: zio/aws/docdb/model/RemoveFromGlobalClusterResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class RemoveFromGlobalClusterResponse(
    globalCluster: Option[zio.aws.docdb.model.GlobalCluster] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.RemoveFromGlobalClusterResponse = {
    import RemoveFromGlobalClusterResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.RemoveFromGlobalClusterResponse
      .builder()
      .optionallyWith(globalCluster.map(value => value.buildAwsValue()))(
        _.globalCluster
      )
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.RemoveFromGlobalClusterResponse.ReadOnly =
    zio.aws.docdb.model.RemoveFromGlobalClusterResponse.wrap(buildAwsValue())
}
object RemoveFromGlobalClusterResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.RemoveFromGlobalClusterResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.RemoveFromGlobalClusterResponse =
      zio.aws.docdb.model.RemoveFromGlobalClusterResponse(
        globalCluster.map(value => value.asEditable)
      )
    def globalCluster: Option[zio.aws.docdb.model.GlobalCluster.ReadOnly]
    def getGlobalCluster
        : ZIO[Any, AwsError, zio.aws.docdb.model.GlobalCluster.ReadOnly] =
      AwsError.unwrapOptionField("globalCluster", globalCluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.RemoveFromGlobalClusterResponse
  ) extends zio.aws.docdb.model.RemoveFromGlobalClusterResponse.ReadOnly {
    override val globalCluster
        : Option[zio.aws.docdb.model.GlobalCluster.ReadOnly] = scala
      .Option(impl.globalCluster())
      .map(value => zio.aws.docdb.model.GlobalCluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.RemoveFromGlobalClusterResponse
  ): zio.aws.docdb.model.RemoveFromGlobalClusterResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-docdb_2.13-6.20.61.1-sources.jar: zio/aws/docdb/model/RemoveFromGlobalClusterResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RemoveFromGlobalClusterResponse(
    globalCluster: Optional[zio.aws.docdb.model.GlobalCluster] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.RemoveFromGlobalClusterResponse = {
    import RemoveFromGlobalClusterResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.RemoveFromGlobalClusterResponse
      .builder()
      .optionallyWith(globalCluster.map(value => value.buildAwsValue()))(
        _.globalCluster
      )
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.RemoveFromGlobalClusterResponse.ReadOnly =
    zio.aws.docdb.model.RemoveFromGlobalClusterResponse.wrap(buildAwsValue())
}
object RemoveFromGlobalClusterResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.RemoveFromGlobalClusterResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.RemoveFromGlobalClusterResponse =
      zio.aws.docdb.model.RemoveFromGlobalClusterResponse(
        globalCluster.map(value => value.asEditable)
      )
    def globalCluster: Optional[zio.aws.docdb.model.GlobalCluster.ReadOnly]
    def getGlobalCluster
        : ZIO[Any, AwsError, zio.aws.docdb.model.GlobalCluster.ReadOnly] =
      AwsError.unwrapOptionField("globalCluster", globalCluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.RemoveFromGlobalClusterResponse
  ) extends zio.aws.docdb.model.RemoveFromGlobalClusterResponse.ReadOnly {
    override val globalCluster
        : Optional[zio.aws.docdb.model.GlobalCluster.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.globalCluster())
        .map(value => zio.aws.docdb.model.GlobalCluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.RemoveFromGlobalClusterResponse
  ): zio.aws.docdb.model.RemoveFromGlobalClusterResponse.ReadOnly = new Wrapper(
    impl
  )
}
